# Simdak

[![simdak - PyPi](https://img.shields.io/pypi/v/simdak)](https://pypi.org/project/simdak/)
[![Tutorial](https://img.shields.io/badge/Tutorial-Penggunaan-informational)](docs/README.md)
[![Group Telegram](https://img.shields.io/badge/Telegram-Group-blue.svg)](https://t.me/simdak_paud)

Python client module Simdak Kemdikbud

## Fitur

Fitur export dan import data _Simdak Paud-Dikmas_.

## Legal / Hukum

Kode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh [Kemdikbud](https://kemdikbud.go.id/) atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri._
